@@ -91,7 +91,6 @@ void Output::readInGlobalPartFromInfo(KScreen::OutputPtr output, const QVariantM
     output->setVrrPolicy(config.vrrPolicy.value_or(KScreen::Output::VrrPolicy::Automatic));
     output->setOverscan(config.overscan.value_or(0));
     output->setRgbRange(config.rgbRange.value_or(KScreen::Output::RgbRange::Automatic));
-    output->setEnabled(true); // gets disabled later if necessary
 
     KScreen::ModePtr matchingMode;
     if (config.modeId) {
@@ -400,6 +399,7 @@ void Output::readInOutputs(KScreen::ConfigPtr config, const QVariantList &output
                                        " or a different device with the same serial number has been connected (very unlikely).";
             if (!readInGlobal(output)) {
                 // set some default values instead
+                output->setEnabled(true);
                 readInGlobalPartFromInfo(output, QVariantMap());
             }
         }
